==> ugene_1.19.0%2Bdfsg.orig.tar.xz: ugene-1.19.0/src/plugins/external_tool_support/src/spades/SpadesSettingsWidget.h <==
/**
 * UGENE - Integrated Bioinformatics Tools.
 * Copyright (C) 2008-2015 UniPro <ugene@unipro.ru>
 * http://ugene.unipro.ru
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */

#ifndef _U2_SPADES_SETTINGS_WIDGET_H_
#define _U2_SPADES_SETTINGS_WIDGET_H_

#include <U2Algorithm/GenomeAssemblyRegistry.h>

#include <U2View/DnaAssemblyGUIExtension.h>

#include "ui/ui_SpadesSettings.h"

namespace U2 {


class SpadesSettingsWidget : public GenomeAssemblyAlgorithmMainWidget, Ui_SpadesSettings {
    Q_OBJECT
public:
    SpadesSettingsWidget(QWidget *parent);
    QMap<QString, QVariant> getGenomeAssemblyCustomSettings();
    bool isParametersOk(QString &);
};

class SpadesGUIExtensionsFactory : public GenomeAssemblyGUIExtensionsFactory {
    GenomeAssemblyAlgorithmMainWidget *createMainWidget(QWidget *parent);
    bool hasMainWidget();
};



} // namespace U2

#endif // _U2_SPADES_SETTINGS_WIDGET_H_

==> ugene_1.25.0%2Bdfsg.orig.tar.xz: ugene-1.25.0/src/plugins/external_tool_support/src/spades/SpadesSettingsWidget.h <==
/**
 * UGENE - Integrated Bioinformatics Tools.
 * Copyright (C) 2008-2016 UniPro <ugene@unipro.ru>
 * http://ugene.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */

#ifndef _U2_SPADES_SETTINGS_WIDGET_H_
#define _U2_SPADES_SETTINGS_WIDGET_H_

#include <U2Algorithm/GenomeAssemblyRegistry.h>
#include <U2Gui/U2SavableWidget.h>
#include <U2View/DnaAssemblyGUIExtension.h>

#include "ui_SpadesSettings.h"

namespace U2 {


class SpadesSettingsWidget : public GenomeAssemblyAlgorithmMainWidget, Ui_SpadesSettings, U2SavableWidget {
    Q_OBJECT
public:
    SpadesSettingsWidget(QWidget *parent);
    QMap<QString, QVariant> getGenomeAssemblyCustomSettings();
    bool isParametersOk(QString &);
};

class SpadesGUIExtensionsFactory : public GenomeAssemblyGUIExtensionsFactory {
    GenomeAssemblyAlgorithmMainWidget *createMainWidget(QWidget *parent);
    bool hasMainWidget();
};



} // namespace U2

#endif // _U2_SPADES_SETTINGS_WIDGET_H_
